@@ -5,6 +5,7 @@
 #' @param data Numerical values to be plotted
 #' @param well Vector of well identifiers e.g "A01"
 #' @param plate Number of wells in complete plate (96, 384 or 1536)
+#' @param ... additional parameters to plot wrappers
 #'
 #' @import ggplot2
 #'
@@ -20,8 +21,7 @@
 #'         well = df$well,
 #'         plate = 384)
 
-raw_map <- function(data, well,
-                    plate = 96) {
+raw_map <- function(data, well, plate = 96, ...) {
 
     check_plate_input(well, plate)
 
@@ -29,16 +29,16 @@ raw_map <- function(data, well,
     platemap <- plate_map(data, well)
 
     if (plate == 96){
-    plt <- plt96(platemap) +
-        theme_bw()
+    plt <- plt96(platemap, ...) + theme_bw()
+
     } else if (plate == 384){
-    plt <- plt384(platemap) +
-        theme_bw()
+    plt <- plt384(platemap, ...) + theme_bw()
+
     } else if (plate == 1536L){
-    plt <- plt1536(platemap) +
-        theme_bw()
+    plt <- plt1536(platemap, ...) + theme_bw()
+
     } else{
-    stop("Invalid argument for 'plate'. \nOption: 96, 384 or 1546",
+    stop("Invalid argument for 'plate'. \nOption: 96, 384 or 1536",
         call. = FALSE)
     }
 
