@@ -9,7 +9,6 @@
 #' @param verbose Boolean, if TRUE will add row and column numbers to dataframe
 #' @param new_col_name What to call the added metadata
 #'
-#' @import dplyr
 #' @importFrom utils read.csv
 #'
 #' @export
@@ -17,32 +16,28 @@
 #' @return dataframe with new column named after `new_col_name`
 
 
-read_map <- function (data, map,
-                      verbose = TRUE,
-                      new_col_name = "header"){
+read_map <- function (data, map, verbose = TRUE, new_col_name = "header") {
 
     if (is.character(map) == TRUE) {
-    map <- as.matrix(read.csv(map, header = FALSE))
+        map <- as.matrix(read.csv(map, header = FALSE))
     }
-    map <- as.matrix(map)
-    platemap <- mutate(data,
-    row = as.numeric(match(toupper(substr(data$well,1, 1)), LETTERS)),
-        column = as.numeric(substr(data$well, 2, 5)))
 
+    map <- as.matrix(map)
+    platemap <- data
+    platemap$row <- as.numeric(match(toupper(substr(data$well,1, 1)), LETTERS))
+    platemap$column <- as.numeric(substr(data$well, 2, 5))
     platemap$header <- NULL
 
     for (i in 1:nrow(data)) {
-    platemap$header[i] <- as.vector(with(platemap,
-                                         map[[row[i],column[i]]]))
+        platemap$header[i] <- as.vector(with(platemap, map[[row[i],column[i]]]))
     }
 
     names(platemap)[ncol(platemap)] <- new_col_name
 
     if (verbose == FALSE) {
-    platemap$row <- NULL
-    platemap$column <- NULL
+        platemap$row <- NULL
+        platemap$column <- NULL
+    }
+
     return(platemap)
-    } else if (verbose == TRUE) {
-    return(platemap)
-    } else stop("Argument 'verbose' requires a boolean.", call. = FALSE)
 }
